'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _rollupPluginBabelHelpers = require('./_virtual/_rollupPluginBabelHelpers.cjs');
var umi = require('@metaplex-foundation/umi');

/** @category Errors */
class BeetSerializerError extends umi.UmiError {
  constructor(message, cause) {
    super(message, 'plugin', 'Beet Serializer', cause);
    _rollupPluginBabelHelpers.defineProperty(this, "name", 'BeetSerializerError');
  }
}
class OperationNotSupportedError extends BeetSerializerError {
  constructor(operation) {
    super(`The operation [${operation}] is ` + `not supported by the Beet Serializer.`);
    _rollupPluginBabelHelpers.defineProperty(this, "name", 'OperationNotSupportedError');
  }
}
class DeserializingEmptyBufferError extends BeetSerializerError {
  constructor(serializer) {
    super(`Serializer [${serializer}] cannot deserialize empty buffers.`);
    _rollupPluginBabelHelpers.defineProperty(this, "name", 'DeserializingEmptyBufferError');
  }
}
class NotEnoughBytesError extends BeetSerializerError {
  constructor(serializer, expected, actual) {
    super(`Serializer [${serializer}] expected ${expected} bytes, got ${actual}.`);
    _rollupPluginBabelHelpers.defineProperty(this, "name", 'NotEnoughBytesError');
  }
}

exports.BeetSerializerError = BeetSerializerError;
exports.DeserializingEmptyBufferError = DeserializingEmptyBufferError;
exports.NotEnoughBytesError = NotEnoughBytesError;
exports.OperationNotSupportedError = OperationNotSupportedError;
//# sourceMappingURL=errors.cjs.map
