import { defineProperty as _defineProperty } from './_virtual/_rollupPluginBabelHelpers.mjs';
import { UmiError } from '@metaplex-foundation/umi';

/** @category Errors */
class BeetSerializerError extends UmiError {
  constructor(message, cause) {
    super(message, 'plugin', 'Beet Serializer', cause);
    _defineProperty(this, "name", 'BeetSerializerError');
  }
}
class OperationNotSupportedError extends BeetSerializerError {
  constructor(operation) {
    super(`The operation [${operation}] is ` + `not supported by the Beet Serializer.`);
    _defineProperty(this, "name", 'OperationNotSupportedError');
  }
}
class DeserializingEmptyBufferError extends BeetSerializerError {
  constructor(serializer) {
    super(`Serializer [${serializer}] cannot deserialize empty buffers.`);
    _defineProperty(this, "name", 'DeserializingEmptyBufferError');
  }
}
class NotEnoughBytesError extends BeetSerializerError {
  constructor(serializer, expected, actual) {
    super(`Serializer [${serializer}] expected ${expected} bytes, got ${actual}.`);
    _defineProperty(this, "name", 'NotEnoughBytesError');
  }
}

export { BeetSerializerError, DeserializingEmptyBufferError, NotEnoughBytesError, OperationNotSupportedError };
//# sourceMappingURL=errors.mjs.map
